package java.lang;

import java.util.concurrent.TimeUnit;
import java.io.InputStream;
import java.io.OutputStream;

public abstract class Process
{
    public Process() {
    }
    
    public abstract OutputStream getOutputStream();
    
    public abstract InputStream getInputStream();
    
    public abstract InputStream getErrorStream();
    
    public abstract int waitFor() throws InterruptedException;
    
    public boolean waitFor(long n, TimeUnit timeUnit) throws InterruptedException {
        long nanoTime = System.nanoTime();
        long nanos = timeUnit.toNanos(n);
        Label_0012: {
            try {
                this.exitValue();
                return true;
            }
            catch (IllegalThreadStateException ex) {
                if (nanos > 0L) {
                    Thread.sleep(Math.min(TimeUnit.NANOSECONDS.toMillis(nanos) + 1L, 100L));
                }
                nanos = timeUnit.toNanos(n) - (System.nanoTime() - nanoTime);
                if (nanos > 0L) {
                    continue;
                }
                return false;
            }
        }
    }
    
    public abstract int exitValue();
    
    public abstract void destroy();
    
    public Process destroyForcibly() {
        this.destroy();
        return this;
    }
    
    public boolean isAlive() {
        try {
            this.exitValue();
            return false;
        }
        catch (IllegalThreadStateException ex) {
            return true;
        }
    }
}
